RubixCube
=========

Python GUI Rubix Cube Solver

Author : [David Grethlein](https://davidgrethlein.dev) :nerd_face: :cowboy_hat_face: :robot:

CS 530 : Developing User Interfaces
Final Project Rubix Cube Python GUI 


Project Documentation
=====================

[GitHub Pages](https://dgrethlein.github.io/RubixCube/) :memo:

[![Docs Preview](./misc/docs_preview.png)](https://dgrethlein.github.io/RubixCube/)

PyPI Installation
=================

[PyPI Hosting](https://pypi.org/project/rubix-cube/) :file_folder:

```bash
pip install rubix-cube
```

[![PyPI Preview](./misc/pypi_preview.png)](https://pypi.org/project/rubix-cube/)